#!/usr/bin/env seed
// Returns: 0
// STDIN:2+2
// STDOUT:4
// STDERR:

readline = imports.readline;
print(eval(readline.readline("")));
